Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1250)

Unified Diff: third_party/WebKit/Tools/Scripts/webkitpy/w3c/local_wpt.py

Issue 2703663005: [WPT Export] Use github remote, not origin (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Tools/Scripts/webkitpy/w3c/local_wpt.py
diff --git a/third_party/WebKit/Tools/Scripts/webkitpy/w3c/local_wpt.py b/third_party/WebKit/Tools/Scripts/webkitpy/w3c/local_wpt.py
index 0081f9e6ad1327ba7502ba2fc31c1cc96a64773e..eb0419c2cafef88d5f3ac4b369eaf3a4c565c09b 100644
--- a/third_party/WebKit/Tools/Scripts/webkitpy/w3c/local_wpt.py
+++ b/third_party/WebKit/Tools/Scripts/webkitpy/w3c/local_wpt.py
@@ -35,7 +35,7 @@ class LocalWPT(object):
if self.host.filesystem.exists(self.path):
_log.info('WPT checkout exists at %s, fetching latest', self.path)
self.run(['git', 'fetch', '--all'])
- self.run(['git', 'checkout', 'origin/master'])
+ self.run(['git', 'checkout', 'github/master'])
else:
_log.info('Cloning %s into %s', WPT_REPO_URL, self.path)
qyearsley 2017/02/17 19:18:41 Question: Would it make sense to change this to us
self.host.executive.run_command(['git', 'clone', WPT_REPO_URL, self.path])
@@ -64,7 +64,7 @@ class LocalWPT(object):
def clean(self):
self.run(['git', 'reset', '--hard', 'HEAD'])
self.run(['git', 'clean', '-fdx'])
- self.run(['git', 'checkout', 'origin/master'])
+ self.run(['git', 'checkout', 'github/master'])
if self.branch_name in self.all_branches():
self.run(['git', 'branch', '-D', self.branch_name])
@@ -102,7 +102,7 @@ class LocalWPT(object):
return self.branch_name
def test_patch(self, patch, chromium_commit=None):
"""Returns the expected output of a patch against origin/master.
Args:
patch: The patch to test against.
@@ -118,7 +118,7 @@ class LocalWPT(object):
try:
self.run(['git', 'apply', '-'], input=patch)
self.run(['git', 'add', '.'])
- output = self.run(['git', 'diff', 'origin/master'])
+ output = self.run(['git', 'diff', 'github/master'])
except ScriptError:
_log.warning('Patch did not apply cleanly, skipping.')
if chromium_commit:
@@ -130,11 +130,11 @@ class LocalWPT(object):
return output
def commits_behind_master(self, commit):
"""Returns the number of commits after the given commit on origin/master.
This doesn't include the given commit, and this assumes that the given
commit is on the the master branch.
"""
return len(self.run([
- 'git', 'rev-list', '{}..origin/master'.format(commit)
+ 'git', 'rev-list', '{}..github/master'.format(commit)
]).splitlines())
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -102,7 +102,7 @@ class LocalWPT(object):
return self.branch_name
def test_patch(self, patch, chromium_commit=None):
- """Returns the expected output of a patch against origin/master.
+ """Returns the expected output of a patch against github/master.
Args:
patch: The patch to test against.
@@ -130,11 +130,11 @@ class LocalWPT(object):
return output
def commits_behind_master(self, commit):
- """Returns the number of commits after the given commit on origin/master.
+ """Returns the number of commits after the given commit on github/master.
This doesn't include the given commit, and this assumes that the given
commit is on the the master branch.

Powered by Google App Engine
This is Rietveld 408576698